==> PyBookReader-0.4.8.tar.gz: PyBookReader-0.4.8/setup.py <==
#!/usr/bin/env python
# -*- mode: python; coding: koi8-r -*-


import sys
import os
from distutils.core import setup, Extension
from distutils.command.install_data import install_data

from pybookreader.config import program_version

BUILD_FB2_SUPPORT = 1


class my_install_data(install_data):
    # for install pybookreader.glade to library dir
    # (from setup.py wxPython)
    def run(self):
        #need to change self.install_dir to the actual library dir
        install_cmd = self.get_finalized_command('install')
        self.install_dir = getattr(install_cmd, 'install_lib')
        return install_data.run(self)

ext_modules = []

## build FictionBook 2 support
if BUILD_FB2_SUPPORT:
    xml2_libs = os.popen('xml2-config --libs', 'r').read()[:-1]
    xml2_cflags = os.popen('xml2-config --cflags', 'r').read()[:-1]
    ext = Extension('pybookreader.fb2wrap',
                    ['pybookreader/fb2parser.c',
                     'pybookreader/fb2parser_wrap.c'],
                    extra_compile_args = [xml2_cflags],
                    extra_link_args = [xml2_libs],
                    )
    ext_modules.append(ext)

setup(
    name = 'PyBookReader',
    version = program_version,
    url = 'http://pybookreader.narod.ru',
    author = 'Con Radchenko',
    author_email = 'pybookreader@narod.ru',
    description = 'PyBookReader is a PyGTK-based GUI book reader.',
    license = 'GPL',
    scripts = ['pybr'],
    packages = ['pybookreader', 'pybookreader.dictclient'],
    ext_modules = ext_modules,
    cmdclass = {'install_data': my_install_data},
    data_files = [ ('pybookreader',
                    ['pybookreader/pybookreader.glade']),
                   ('pybookreader/dictclient',
                    ['pybookreader/dictclient/pygtkdict.glade'])
                   ],
    )

==> PyBookReader-0.4.11.tar.gz: PyBookReader-0.4.11/setup.py <==
#!/usr/bin/env python
# -*- mode: python; coding: koi8-r -*-


import sys
import os
from distutils.core import setup, Extension
from distutils.command.install_data import install_data

from pybookreader.config import program_version

BUILD_FB2_SUPPORT = 1


class my_install_data(install_data):
    # for install data files to library dir
    def run(self):
        #need to change self.install_dir to the actual library dir
        install_cmd = self.get_finalized_command('install')
        self.install_dir = getattr(install_cmd, 'install_lib')
        return install_data.run(self)

ext_modules = []

## build FictionBook2 support
if BUILD_FB2_SUPPORT:
    xml2_libs = os.popen('xml2-config --libs', 'r').read().split()
    xml2_cflags = os.popen('xml2-config --cflags', 'r').read().split()
    ext = Extension('pybookreader.fb2wrap',
                    ['pybookreader/fb2parser.c',
                     'pybookreader/fb2parser_wrap.c'],
                    extra_compile_args = xml2_cflags,
                    extra_link_args = xml2_libs,
                    )
    ext_modules.append(ext)

setup(
    name = 'PyBookReader',
    version = program_version,
    url = 'http://pybookreader.narod.ru',
    author = 'Con Radchenko',
    author_email = 'pybookreader@narod.ru',
    description = 'PyBookReader is a PyGTK-based GUI book reader.',
    license = 'GPL',
    scripts = ['pybr'],
    packages = ['pybookreader', 'pybookreader.dictclient'],
    ext_modules = ext_modules,
    cmdclass = {'install_data': my_install_data},
    data_files = [ ('pybookreader',
                    ['pybookreader/pybookreader.glade']),
                   ('pybookreader/dictclient',
                    ['pybookreader/dictclient/pygtkdict.glade'])
                   ],
    )
